smartcard.ReaderMonitoring.ReaderMonitoringThread

# ``smartcard`.`ReaderMonitoring`.`ReaderMonitoringThread``

class documentation

`class ReaderMonitoringThread(Thread):`

View In Hierarchy

Reader insertion thread. This thread polls for pcsc reader insertion, since no reader insertion event is available in pcsc.

Method | `__init__` | Undocumented
Method | `run` | Runs until stopEvent is notified, and notify observers of all reader insertion/removal.
Method | `stop` | Undocumented
Instance Variable | `__dict__` | Undocumented
Instance Variable | `observable` | Undocumented
Instance Variable | `period` | Undocumented
Instance Variable | `readerProc` | Undocumented
Instance Variable | `readers` | Undocumented
Instance Variable | `stopEvent` | Undocumented
Class Variable | `__shared_state` | Undocumented

def __init__(self, observable, readerProc, period):

Undocumented

def run(self):

Runs until stopEvent is notified, and notify observers of all reader insertion/removal.

def stop(self):

Undocumented

__dict__ =

Undocumented

observable =

Undocumented

period =

Undocumented

readerProc =

Undocumented

readers: `list` =

Undocumented

stopEvent =

Undocumented

__shared_state: `dict` =

Undocumented